OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Fehler beim Verarbeiten der Protokolldatei",
    "Copy" : "Kopieren",
    "Copy raw" : "Rohformat kopieren",
    "Copy formatted" : "Formatiert kopieren",
    "No server logs" : "Keine Server-Log-Dateien",
    "One or more entries are hidden by the log level filter" : "Ein oder mehrere Einträge sind versteckt durch die Log-Level-Filter",
    "Everything is working fine" : "Alles funktioniert gut",
    "Level" : "Level",
    "App" : "App",
    "Message" : "Nachricht",
    "Time" : "Zeit",
    "Log levels" : "Log-Level",
    "Log content" : "Log-Inhalt",
    "Live update" : "Live-Aktualisierung",
    "Download logs" : "Protokolldatei herunterladen",
    "Logging" : "Protokollierung",
    "Log Reader" : "Log-Datei-Leser",
    "A log reader for Nextcloud" : "Ein Log-Datei-Leser für Nextcloud",
    "Log reader for Nextcloud" : "Log-Datei-Leser für Nextcloud",
    "Cased by " : "Verursacht von"
},
"nplurals=2; plural=(n != 1);");
